import { TaskSpec } from '../types';
import { TaskRuntime } from './task-runtime';
export declare class Task {
    private readonly runtime;
    private readonly task;
    private readonly env;
    private readonly parents;
    private readonly workdir;
    constructor(runtime: TaskRuntime, task: TaskSpec, parents?: string[]);
    /**
     * Executes steps in a given task
     */
    private execute;
    /**
     * Determines if a task should be executed based on "condition".
     *
     * @returns true if the task should be executed or false if the condition
     * evaluates to false (exits with non-zero), indicating that the task should
     * be skipped.
     */
    private evalCondition;
    /**
     * Renders the runtime environment for a task. Namely, it supports this syntax
     * `$(xx)` for allowing environment to be evaluated by executing a shell
     * command and obtaining its result.
     */
    private resolveEnvironment;
    /**
     * Returns the "full name" of the task which includes all it's parent task names concatenated by chevrons.
     */
    private get fullname();
    private log;
    private logDebug;
    private fmtLog;
    private shell;
    private shellEval;
    private resolveBuiltin;
}
//# sourceMappingURL=task.d.ts.map